@@ -801,326 +801,6 @@ def plan(om, Nd, Kd, Jd, ft_axes = None, format='CSR', radix = None):
 
     return st #new
 
-def plan1(om, Nd, Kd, Jd, ft_axes = None):
-    """
-    Compute the coil sensitivity aware interpolator
-    """
-#         self.debug = 0  # debug
-
-    if type(Nd) != tuple:
-        raise TypeError('Nd must be tuple, e.g. (256, 256)')
-
-    if type(Kd) != tuple:
-        raise TypeError('Kd must be tuple, e.g. (512, 512)')
-
-    if type(Jd) != tuple:
-        raise TypeError('Jd must be tuple, e.g. (6, 6)')
-
-    if (len(Nd) != len(Kd)) | (len(Nd) != len(Jd))  | len(Kd) != len(Jd):
-        raise KeyError('Nd, Kd, Jd must be in the same length, e.g. Nd=(256,256),Kd=(512,512),Jd=(6,6)')
-
-    dd = numpy.size(Nd)
-
-    if ft_axes is None:
-        ft_axes = tuple(xx for xx in range(0, dd))
-
-#     print('ft_axes = ', ft_axes)
-    ft_flag = () # tensor
-
-    for pp in range(0, dd):
-        if pp in ft_axes:
-            ft_flag += (True, )
-        else:
-            ft_flag += (False, )
-
-    st = {}
-
-
-    st['tol'] = 0
-    st['Jd'] = Jd
-    st['Nd'] = Nd
-    st['Kd'] = Kd
-    M = om.shape[0]
-    st['M'] = numpy.int32(M)
-    st['om'] = om
-
-
-    for dimid in range(0, dd):
-
-        (tmp_alpha, tmp_beta) = nufft_alpha_kb_fit(
-            Nd[dimid], Jd[dimid], Kd[dimid])
-        st.setdefault('alpha', []).append(tmp_alpha)
-        st.setdefault('beta', []).append(tmp_beta)
-
-    snd = ()
-    list_C = []
-    list_arg = []
-    list_bn = []
-    for dimid in range(0, dd):
-        snd += (nufft_scale(
-            Nd[dimid],
-            Kd[dimid],
-            st['alpha'][dimid],
-            st['beta'][dimid]), )
-        C, arg, bn = QR_process(om[:, dimid], Nd[dimid], Jd[dimid], Kd[dimid], snd[dimid])
-        """
-        Save the C matrix, arg and bn. They will be reused.
-        """
-        list_C += [C, ]
-        list_arg += [arg, ]
-        list_bn += [bn, ]
-    st['sn'] = kronecker_scale(snd).real # only real scaling is relevant
-
-    # [J? M] interpolation coefficient vectors.
-    # Iterate over all dimensions and
-    # multiply the coefficients of all dimensions
-
-    ud = []
-    for dimid in range(0, dd):  # iterate through all dimensions
-        N = Nd[dimid]
-        J = Jd[dimid]
-        K = Kd[dimid]
-        alpha = st['alpha'][dimid]
-        beta = st['beta'][dimid]
-
-        """
-        Compute the coil sensitivity aware interpolator
-        """
-
-        if ft_flag[dimid] is True:
-
-            c = solve_c( list_C[dimid],  list_bn[dimid])
-            # C: NxJ,
-            # bn: NxM (xr)
-            # c: J x M    (x    r)
-
-            u2 = OMEGA_u( c, N, K, om[:, dimid], list_arg[dimid], ft_flag[dimid]).T.conj()
-            # u2: J x M    (x    r)
-
-            ud += [u2,]
-
-        else:
-            ud += (numpy.ones((1, M), dtype = dtype).T, )
-
-    """
-    Now compute the column indeces for 1D interpolators
-    Each length-Jd interpolator includes Jd points, which are linked to Jd k-space locations
-    kd is a tuple storing the 1D interpolators.
-    A following Kronecker product will be needed.
-    """
-
-    kd = []
-    for dimid in range(0, dd):  # iterate over all dimensions
-        kd += (OMEGA_k(J,K, om[:,dimid], Kd, dimid, dd, ft_flag[dimid]).T, )
-
-    CSR, ELL = full_kron(ud, kd, Jd, Kd, M)
-    st['p'] = CSR
-
-    return st #new
-
-def plan0(om, Nd, Kd, Jd):
-#         self.debug = 0  # debug
-
-    if type(Nd) != tuple:
-        raise TypeError('Nd must be tuple, e.g. (256, 256)')
-
-    if type(Kd) != tuple:
-        raise TypeError('Kd must be tuple, e.g. (512, 512)')
-
-    if type(Jd) != tuple:
-        raise TypeError('Jd must be tuple, e.g. (6, 6)')
-
-    if (len(Nd) != len(Kd)) | (len(Nd) != len(Jd))  | len(Kd) != len(Jd):
-        raise KeyError('Nd, Kd, Jd must be in the same length, e.g. Nd=(256,256),Kd=(512,512),Jd=(6,6)')
-
-    dd = numpy.size(Nd)
-
-###############################################################
-# check input errors
-###############################################################
-    st = {}
-    ud = {}
-    kd = {}
-
-###############################################################
-# First, get alpha and beta: the weighting and freq
-# of formula (28) in Fessler's paper
-# in order to create slow-varying image space scaling
-###############################################################
-    for dimid in range(0, dd):
-        (tmp_alpha, tmp_beta) = nufft_alpha_kb_fit(
-            Nd[dimid], Jd[dimid], Kd[dimid])
-        st.setdefault('alpha', []).append(tmp_alpha)
-        st.setdefault('beta', []).append(tmp_beta)
-    st['tol'] = 0
-    st['Jd'] = Jd
-    st['Nd'] = Nd
-    st['Kd'] = Kd
-    M = om.shape[0]
-    st['M'] = numpy.int32(M)
-    st['om'] = om
-    st['sn'] = numpy.array(1.0 + 0.0j)
-    dimid_cnt = 1
-###############################################################
-# create scaling factors st['sn'] given alpha/beta
-# higher dimension implementation
-###############################################################
-    for dimid in range(0, dd):
-        tmp = nufft_scale(
-            Nd[dimid],
-            Kd[dimid],
-            st['alpha'][dimid],
-            st['beta'][dimid])
-        dimid_cnt = Nd[dimid] * dimid_cnt
-###############################################################
-# higher dimension implementation: multiply over all dimension
-###############################################################
-        st['sn'] = numpy.dot(st['sn'], tmp.T)
-        st['sn'] = numpy.reshape(st['sn'], (dimid_cnt, 1), order='C')
-        # JML do not apply scaling
-
-    # order = 'F' is for fortran order
-    st['sn'] = st['sn'].reshape(Nd, order='C')  # [(Nd)]
-    ###############################################################
-    # else:
-    #     st['sn'] = numpy.array(st['sn'],order='F')
-    ###############################################################
-
-    st['sn'] = numpy.real(st['sn'])  # only real scaling is relevant
-
-    # [J? M] interpolation coefficient vectors.
-    # Iterate over all dimensions and
-    # multiply the coefficients of all dimensions
-    for dimid in range(0, dd):  # loop over dimensions
-        N = Nd[dimid]
-        J = Jd[dimid]
-        K = Kd[dimid]
-        alpha = st['alpha'][dimid]
-        beta = st['beta'][dimid]
-        ###############################################################
-        # formula 29 , 26 of Fessler's paper
-        ###############################################################
-
-        # pseudo-inverse of CSSC using large N approx [J? J?]
-        T = nufft_T(N, J, K, alpha, beta)
-        ###############################################################
-        # formula 30  of Fessler's paper
-        ###############################################################
-
-        (r, arg) = nufft_r(om[:, dimid], N, J,
-                           K, alpha, beta)  # large N approx [J? M]
-
-        ###############################################################
-        # formula 25  of Fessler's paper
-        ###############################################################
-        c = numpy.dot(T, r)
-
-        ###############################################################
-        # grid intervals in radius
-        ###############################################################
-        gam = 2.0 * numpy.pi / (K * 1.0)
-
-        phase_scale = 1.0j * gam * (N - 1.0) / 2.0
-        phase = numpy.exp(phase_scale * arg)  # [J? M] linear phase
-        ud[dimid] = phase * c
-        # indices into oversampled FFT components
-        # FORMULA 7
-        koff = nufft_offset(om[:, dimid], J, K)
-        # FORMULA 9, find the indexes on Kd grids, of each M point
-        kd[dimid] = numpy.mod(
-            outer_sum(
-                numpy.arange(
-                    1,
-                    J + 1) * 1.0,
-                koff),
-            K)
-
-        """
-            JML: For GPU computing, indexing must be C-order (row-major)
-            Multi-dimensional cuda or opencl arrays are row-major (order="C"), which  starts from the higher dimension.
-            Note: This is different from the MATLAB indexing(for fortran order, colum major, low-dimension first
-        """
-
-        if dimid < dd - 1:  # trick: pre-convert these indices into offsets!
-            #            ('trick: pre-convert these indices into offsets!')
-            kd[dimid] = kd[dimid] * numpy.prod(Kd[dimid+1:dd]) - 1
-        """
-        Note: F-order matrices must be reshaped into an 1D array before sparse matrix-vector multiplication.
-        The original F-order (in Fessler and Sutton 2003) is not suitable for GPU array (C-order).
-        Currently, in-place reshaping in F-order only works in numpy.
-
-        """
-#             if dimid > 0:  # trick: pre-convert these indices into offsets!
-#                 #            ('trick: pre-convert these indices into offsets!')
-#                 kd[dimid] = kd[dimid] * numpy.prod(Kd[0:dimid]) - 1
-
-    kk = kd[0]  # [J1 M] # pointers to indices
-    uu = ud[0]  # [J1 M]
-    Jprod = Jd[0]
-    Kprod = Kd[0]
-    for dimid in range(1, dd):
-        Jprod = numpy.prod(Jd[:dimid + 1])
-        Kprod = numpy.prod(Kd[:dimid + 1])
-        kk = block_outer_sum0(kk, kd[dimid]) + 1  # outer sum of indices
-        kk = kk.reshape((Jprod, M), order='C')
-        # outer product of coefficients
-        uu = block_outer_prod(uu, ud[dimid])
-        uu = uu.reshape((Jprod, M), order='C')
-        # now kk and uu are [*Jd M]
-        # now kk and uu are [*Jd M]
-    # *numpy.tile(phase,[numpy.prod(Jd),1]) #    product(Jd)xM
-    uu = uu.conj()
-    mm = numpy.arange(0, M)  # indices from 0 to M-1
-    mm = numpy.tile(mm, [numpy.prod(Jd).astype(int), 1])  # product(Jd)xM
-    # Now build sparse matrix from uu, mm, kk
-
-    # convert array to list
-    csrdata = numpy.reshape(uu.T, (Jprod * M, ), order='C')
-
-    # row indices, from 1 to M convert array to list
-    rowindx = numpy.reshape(mm.T, (Jprod * M, ), order='C')
-
-    # colume indices, from 1 to prod(Kd), convert array to list
-    colindx = numpy.reshape(kk.T, (Jprod * M, ), order='C')
-
-    # The shape of sparse matrix
-    csrshape = (M, numpy.prod(Kd))
-
-    # Build sparse matrix (interpolator)
-    st['p'] = scipy.sparse.csr_matrix((csrdata, (rowindx, colindx)),
-                                       shape=csrshape)
-    # Note: the sparse matrix requires the following linear phase,
-    #       which moves the image to the center of the image
-
-    om = st['om']
-    M = st['M']
-
-    n_shift = tuple(0*x for x in st['Nd'])
-
-    final_shifts = tuple(
-        numpy.array(n_shift) +
-        numpy.array(
-            st['Nd']) /
-        2)
-
-    phase = numpy.exp(
-        1.0j *
-        numpy.sum(
-            om *
-            numpy.tile(
-                final_shifts,
-                (M,
-                 1)),
-            1))
-    # add-up all the linear phases in all axes,
-
-    st['p'] = scipy.sparse.diags(phase, 0).dot(st['p'])
-
-
-#     st['p0'].prune() # Scipy sparse: removing empty space after all non-zero elements.
-
-    return st # plan0()
-
 def strides_divide_itemsize(Nd):
     """
     strides_divide_itemsize function computes the step_size (strides/itemsize) along different axes, and its inverse as float32.
