@@ -229,7 +229,7 @@ def atomic_add(API):
         // Now do the imaginary part
         
         do { // atomic add of the value
-            prevVal = *imaglptr ;
+            prevVal = *imagptr ;
             newVal = prevVal + temp.y;
         } while (atomic_cmpxchg((__global volatile unsigned int *)imagptr, as_int(prevVal), as_int(newVal)) != as_int(prevVal));
  
